Installation
============
There are several ways to download and install PyKEEN.

.. warning:: PyKEEN requires Python 3.6+

Easiest
~~~~~~~
The easiest is to use ``pip`` and `PyPI <https://pypi.python.org/pypi/pykeen>`_ in the terminal:

.. code-block:: sh

   $ pip install pykeen

Get the Latest
~~~~~~~~~~~~~~
The latest code can be installed from `GitHub <https://github.com/SmartDataAnalytics/PyKEEN>`_ with:

.. code-block:: sh

   $ pip install git+https://github.com/SmartDataAnalytics/PyKEEN.git

For Developers
~~~~~~~~~~~~~~
The code can be installed in a local development environment with:

.. code-block:: sh

   $ git clone https://github.com/SmartDataAnalytics/PyKEEN.git pykeen
   $ cd pykeen
   $ pip install -e .
